==> savane-1.0.3.1.tar.gz: savane/frontend/php/include/sendmail.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: sendmail.php,v 1.11 2004/03/26 18:45:45 yeupou Exp $
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# Every mails sent should be using functions listed here.

# The function that finally send the mail.
# Every mail sent by Savannah should be using that function which
# works like mail().
# Note: $to can be a coma-separated list.
#       $from and $to can contain user names
function sendmail_mail ($from, 
			$to, 
			$subject, 
			$message, 
			$savannah_project=0, 
			$savannah_artifact=0, 
			$savannah_artifact_id=0, 
			$reply_to=0, 
			$additional_headers=0) 
{
	
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_mail  ';

  # Make sure that users cannot insert malicious content
  $to = stripslashes($to);
  $from = stripslashes($from);
  $subject = stripslashes($subject);
  $message = stripslashes($message);

  # Transform $to in an ordered list, without duplicates
  # (remove blankspaces)
  $xcopy = $to;
  $to = array_unique(explode(",", ereg_replace(" ", "", $to)));

  # If $from is a login name, write nice From: field
  $fromuid = user_getid($from);
  if (user_exists($fromuid)) 
    {
      $from = user_getrealname($fromuid, 1)." <".user_getemail($fromuid).">";
    }

  # Write the add. headers 
  $more_headers = "From: ".$from."\n";
  if ($reply_to)
    { $more_headers .= "Reply-To: ".$reply_to."\n"; }
  $more_headers .= "X-Savane-Server: ".$GLOBALS['SERVER_NAME'].":".$GLOBALS['SERVER_PORT']." [".$GLOBALS['SERVER_ADDR']."]\n";
  if ($savannah_project) 
    { $more_headers .= "X-Savane-Project: ".$savannah_project."\n"; }
  if ($savannah_artifact) 
    { $more_headers .= "X-Savane-Artifact: ".$savannah_artifact."\n"; }  
  if ($savannah_artifact_id) 
    { $more_headers .= "X-Savane-Artifact-ID: ".$savannah_artifact_id."\n"; }
  if ($additional_headers) 
    { $more_headers .= $additional_headers."\n";  }
  $more_headers .= "User-Agent: ".$GLOBALS['HTTP_USER_AGENT']."\n";
  $more_headers .= "X-Apparently-From: ".$GLOBALS['REMOTE_ADDR']."\n";
  
  # Add eventually info on the subject
  if ($savannah_artifact && $savannah_artifact_id) 
    { $subject = "[".$savannah_artifact." #".$savannah_artifact_id."] ".$subject; }
  
  # Add a signature for the server
  $message .= "\n\n_______________________________________________
  ".sprintf(_("Message sent via/by %s"), $GLOBALS['sys_name'])."
  http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."\n";
  
  # Forge the real to list, by parsing every item of the $to list
  unset($real_to);

  while (list($k,$v) = each($to)) 
    {
    # If an address is a username, get the email address from
    # the database.
    # If nothing is found, just let the username - there's maybe a 
    # local alias.
      if (!ereg("@", $v)) 
	{
	  if (user_exists($v)) 
            { $v = user_getrealname($v, 1)." <".user_getemail($v).">"; }
        }
    # If $v is set, add it to the list
    $real_to .= $v.", ";

    } 
 
   # Remove the extra ", " at the end of the list
   $real_to = substr($real_to,0,-2);

   # Send the mail
   if ($real_to) 
	{
	  $ret .= mail($real_to, $subject, $message, $more_headers);
	  fb(sprintf(_("Mail sent to %s"), utils_antispam_email($real_to)));
	} 
      else 
	{
	  fb(_("warning: a mail notification cannot be sent, the To: header being missing. please contact administrators"), 1);
	}
      
  dbg("mail sent to $real_to, $subject, from $from ($fromuid)");
  return $ret; 
}


# A form for logged in users to send mails to others users
function sendmail_form_message ($form_action, $user_id) 
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_form_message ($form_action, $user_id) ';  global $HTML;
  $HTML->box1_top(sprintf(_("Send a Message to %s"),user_getrealname($user_id)));
  print '<p class="warn">'.("If you are writing for help, did you read the project 
documentation first? Try to provide any potentially useful information you can think of.").'</p>';

  # We do not really bother finding out the realname + email, sendmail_mail()
  # will do it.
  print '
 <form action="'.$form_action.'" method="post">
   <input type="hidden" name="touser" value="'.$user_id.'">
   <input type="hidden" name="fromuser" value="'.user_getname().'">

   <p><font class="preinput">'._("From:").'</font> '.user_getrealname(user_getid(), 1).' &lt;'.user_getemail(user_getid()).'&gt;<br />
    <font class="preinput">'._("Mailer:").'</font> '.$GLOBALS['HTTP_USER_AGENT'].' - '.$GLOBALS['REMOTE_ADDR'].'</p>
   <p><font class="preinput">'._("Subject:").'</font><br />
   &nbsp;&nbsp;&nbsp;<input type="text" name="subject" size="60" maxlength="45" value=""></p>
   <p><font class="preinput">'._("Message:").'</font><br />
   &nbsp;&nbsp;&nbsp;<textarea name="body" rows="20" cols="60"></textarea></p>

   <p align="center"><input type="submit" name="send_mail" value="Send Message"></p>
</form>';
  $HTML->box1_bottom();

}


?>

==> savane-1.0.4.tar.gz: savane/frontend/php/include/sendmail.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: sendmail.php,v 1.12 2004/09/22 08:11:51 yeupou Exp $
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# Every mails sent should be using functions listed here.

# The function that finally send the mail.
# Every mail sent by Savannah should be using that function which
# works like mail().
# Note: $to can be a coma-separated list.
#       $from and $to can contain user names
function sendmail_mail ($from, 
			$to, 
			$subject, 
			$message, 
			$savannah_project=0, 
			$savannah_artifact=0, 
			$savannah_artifact_id=0, 
			$reply_to=0, 
			$additional_headers=0) 
{
	
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_mail  ';

  # Make sure that users cannot insert malicious content
  $to = stripslashes($to);
  $from = stripslashes($from);
  $subject = stripslashes($subject);
  $message = stripslashes($message);

  # Convert ; into
  $to = ereg_replace(";", ",", $to);
  # Transform $to in an ordered list, without duplicates
  # (remove blankspaces)
  $to = array_unique(explode(",", ereg_replace(" ", "", $to)));

  # If $from is a login name, write nice From: field
  $fromuid = user_getid($from);
  if (user_exists($fromuid))
    {
      $from = user_getrealname($fromuid, 1)." <".user_getemail($fromuid).">";
    }

  # Write the add. headers 
  $more_headers = "From: ".$from."\n";
  if ($reply_to)
    { $more_headers .= "Reply-To: ".$reply_to."\n"; }
  $more_headers .= "X-Savane-Server: ".$GLOBALS['SERVER_NAME'].":".$GLOBALS['SERVER_PORT']." [".$GLOBALS['SERVER_ADDR']."]\n";
  if ($savannah_project) 
    { $more_headers .= "X-Savane-Project: ".$savannah_project."\n"; }
  if ($savannah_artifact) 
    { $more_headers .= "X-Savane-Tracker: ".$savannah_artifact."\n"; }  
  if ($savannah_artifact_id) 
    { $more_headers .= "X-Savane-Item-ID: ".$savannah_artifact_id."\n"; }
  if ($additional_headers) 
    { $more_headers .= $additional_headers."\n";  }
  $more_headers .= "User-Agent: ".$GLOBALS['HTTP_USER_AGENT']."\n";
  $more_headers .= "X-Apparently-From: ".$GLOBALS['REMOTE_ADDR']."\n";
    
  # Add a signature for the server
  $message .= "\n\n_______________________________________________
  ".sprintf(_("Message sent via/by %s"), $GLOBALS['sys_name'])."
  http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."\n";
  
  # Forge the real to list, by parsing every item of the $to list
  unset($real_to);
  $list = array();
  $user_subject = array();
  $user_name  = array();

  while (list($k,$v) = each($to)) 
    {
      $i++;
      unset($skip);
      # If an address is a username, get the email address from
      # the database.
      # If nothing is found, just let the username - there's maybe a 
      # local alias.
      if (!ereg("@", $v)) 
	{
	  if (user_exists($v)) 
            { 
                # Does the user have a specific subject line?
                if (user_get_preference("subject_line", $v) != "")
                  {
                     $list[$i] = $v;
                     $user_subject[$v] = sendmail_format_subject_line(user_get_preference("subject_line", $v), $savannah_project, $savannah_artifact, $savannah_artifact_id)." ".$subject;
                     $user_name[$v] = user_getrealname($v, 1)." <".user_getemail($v).">";
                     $skip = 1;
                  }

                $v = user_getrealname($v, 1)." <".user_getemail($v).">"; 
            }
        }
    # If $v is set, add it to the list, 
    # unless user want a specific subject line
    if (!$skip)
      { $real_to .= $v.", "; }

    } 

  # Add eventually info on the subject
  if ($savannah_artifact && $savannah_artifact_id) 
    { 
       $subject = "[".$savannah_artifact." #".$savannah_artifact_id."] ".$subject; }
 
   # Remove the extra ", " at the end of the list
   $real_to = substr($real_to,0,-2);

   # Send the mail
   if ($real_to) 
	{
	  $ret .= mail($real_to, $subject, $message, $more_headers);
	  fb(sprintf(_("Mail sent to %s"), utils_antispam_email($real_to)));
	} 
   
   # Send mails with specific subject line
   while (list(,$v) = each($list)) 
     {
        $ret .= mail($user_name[$v], $user_subject[$v], $message, $more_headers);
	fb(sprintf(_("Mail sent to %s"), utils_antispam_email($user_name[$v])));
     }  
      
  dbg("mail sent to $real_to, $subject, from $from ($fromuid)");
  return $ret; 
}


# A form for logged in users to send mails to others users
function sendmail_form_message ($form_action, $user_id) 
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_form_message ($form_action, $user_id) ';  global $HTML;
  $HTML->box1_top(sprintf(_("Send a Message to %s"),user_getrealname($user_id)));
  print '<p class="warn">'.("If you are writing for help, did you read the project 
documentation first? Try to provide any potentially useful information you can think of.").'</p>';

  # We do not really bother finding out the realname + email, sendmail_mail()
  # will do it.
  print '
 <form action="'.$form_action.'" method="post">
   <input type="hidden" name="touser" value="'.$user_id.'">
   <input type="hidden" name="fromuser" value="'.user_getname().'">

   <p><font class="preinput">'._("From:").'</font> '.user_getrealname(user_getid(), 1).' &lt;'.user_getemail(user_getid()).'&gt;<br />
    <font class="preinput">'._("Mailer:").'</font> '.$GLOBALS['HTTP_USER_AGENT'].' - '.$GLOBALS['REMOTE_ADDR'].'</p>
   <p><font class="preinput">'._("Subject:").'</font><br />
   &nbsp;&nbsp;&nbsp;<input type="text" name="subject" size="60" maxlength="45" value=""></p>
   <p><font class="preinput">'._("Message:").'</font><br />
   &nbsp;&nbsp;&nbsp;<textarea name="body" rows="20" cols="60"></textarea></p>

   <p align="center"><input type="submit" name="send_mail" value="Send Message"></p>
</form>';
  $HTML->box1_bottom();
}

function sendmail_format_subject_line ($subject_line, $savannah_project="", $savannah_artifact="", $savannah_artifact_id="") 
{

  $subject_line = ereg_replace("%SERVER", $GLOBALS['sys_default_domain'], $subject_line);
  $subject_line = ereg_replace("%PROJECT", $savannah_project, $subject_line);
  $subject_line = ereg_replace("%TRACKER", $savannah_artifact, $subject_line);
  return ereg_replace("%ITEM", "#".$savannah_artifact_id, $subject_line);
}



?>
